@@ -10,7 +10,7 @@ if __name__ == "__main__":
         description="Validate IDS Artifacts"
     )
 
-    parser.add_argument("ids_dir", type=str, help="Path to the IDS folder")
+    parser.add_argument("--ids_dir", type=str, default=".", required=False, help="Path to the IDS folder")
     parser.add_argument("--version", type=str, required=False, default=None,
                         help=f"Supported Versions: {Conventions.values()}")
     args = parser.parse_args()
